#!/usr/bin/env python
#-*- coding: utf-8 -*-
#Author: Colin
#Date: 2017-04-20
#Desc: 自定义包设计到的初始化配置参数
#

import string 

PASSWD_LENGTH = 16
PASSWD_SEED = string.digits + string.ascii_letters + '!@#$%^&'
